@@ -145,6 +145,16 @@ class DSRequest(RPCRequest):
 
         RPCRequest.__init__(self, self.json)
 
+    def delete_underscore_element(self, data):
+        if not isinstance(data, dict):
+            raise Exception('data must be dict')
+
+        res = dict()
+        for key, value in data.items():
+            if str(key).find('_', 0, 1) == -1:
+                setAttr(res, key, value)
+        return res
+
     def get_data(self, excluded_keys=['grid']):
         res = None
         if isinstance(self.json, dict):
@@ -158,6 +168,7 @@ class DSRequest(RPCRequest):
 
             # res = dict((key, value) for (key, value) in res.items() if not key.startswith('_')  and key not in excluded_keys)
             res = dict((key, value) for (key, value) in res.items() if key not in excluded_keys)
+        # return self.delete_underscore_element(res)
         return res
 
     def get_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
@@ -175,6 +186,7 @@ class DSRequest(RPCRequest):
                 res = self.json
 
             res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
+        # return self.delete_underscore_element(res)
         return res
 
     def get_old_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
