@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField
+from django.db.models import Model, BooleanField, BigAutoField, DateTimeField, Transform, CharField, TextField, Max
 from django.utils import timezone
 
 from isc_common import setAttr
