@@ -109,6 +109,7 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                     where_clause0='',
                     where_clause='',
                     order_by_clause='',
+                    distinct='',
                     sql_text=None,
                     fields='*'
                     ) -> RawQuerySet:
@@ -135,10 +136,10 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                                 JOIN r
                             ON {db_name}.{child_id} = r.{parent_id})
 
-                        select {fields} from r {where_clause} {order_by_clause} limit %s offset %s
+                        select {distinct} {fields} from r {where_clause} {order_by_clause} limit %s offset %s
                         '''
 
-        logger.debug(f'sql: {sql}')
+        # logger.debug(f'sql: {sql}')
         if id is not None:
             res = super().raw(sql, params=((id,), end, start))
         else:
@@ -227,6 +228,7 @@ class TreeAuditModelManager(AuditManager):
                     include_self=True,
                     where_clause0='',
                     where_clause='',
+                    distinct='',
                     order_by_clause='',
                     fields='*',
                     sql_text=None,
@@ -240,6 +242,7 @@ class TreeAuditModelManager(AuditManager):
             include_self=include_self,
             where_clause0=where_clause0,
             where_clause=where_clause,
+            distinct=distinct,
             order_by_clause=order_by_clause,
             fields=fields,
             sql_text=sql_text
